@@ -1,5 +1,5 @@
 use rayon::iter::{ParallelBridge, ParallelIterator};
-use std::path::{Path, PathBuf};
+use std::{path::{Path, PathBuf}};
 
 use crate::structs::{Buffer, FileType, Search};
 
@@ -18,6 +18,7 @@ impl Search {
                     std::process::exit(1);
                 })
             });
+
             // Search in directories
             dirs.par_bridge().for_each(|dir| {
                 search_path(&dir, self);
